@@ -1,4 +1,4 @@
-/* $Id: gdict-pref-dialog.c,v 1.38 2003/07/22 01:04:09 dcransto Exp $ */
+/* $Id: gdict-pref-dialog.c,v 1.39 2003/10/19 06:41:23 kmaraas Exp $ */
 
 /*
  *  Mike Hughes <mfh@psilord.com>
@@ -614,9 +614,7 @@ pref_status_cb (dict_command_t *command, DictStatusCode code,
         
         option_menu = GTK_OPTION_MENU (gtk_option_menu_new ());
         gtk_option_menu_set_menu (option_menu, GTK_WIDGET (use_menu));
-        alignment = gtk_alignment_new (0, 0.5, 0, 0);
-        /*gtk_container_add (GTK_CONTAINER (alignment),
-			   GTK_WIDGET (option_menu));*/
+
         gtk_table_attach_defaults (pref_dialog->table, GTK_WIDGET (option_menu), 
                                    1, 3, row, row + 1);
         gtk_widget_show_all (GTK_WIDGET (pref_dialog->table));
